@@ -15,7 +15,8 @@ def fake_pastaporto_token_for_user(
         {
             "userInfo": {"id": user["id"], "email": user["email"]},
             "credentials": credentials,
-            "exp": datetime.now() + timedelta(minutes=1),
+            "exp": datetime.utcnow() + timedelta(minutes=1),
+            "iss": "gateway",
         },
         secret,
         algorithm="HS256",
@@ -27,7 +28,7 @@ def fake_service_to_service_token(secret: str, *, issuer: str, audience: str):
         {
             "iss": issuer,
             "aud": audience,
-            "exp": datetime.now() + timedelta(minutes=1),
+            "exp": datetime.utcnow() + timedelta(minutes=1),
         },
         secret,
         algorithm="HS256",
